import { Table } from 'antd';
import { Layout } from 'antd';
import useTaskStore from '../../services/taskService';
import { Task, Status as TaskStatus } from '../../interfaces/task';
import { TimePipe } from '../../utils/pipe';
import { Button } from 'antd';
import HeaderNav from '../../components/HeaderNav';
import SideNav from '../../components/SideNav';
import { Status } from './components/TaskStatus';
import { makeStyles } from '@mui/styles';
import { useState } from 'react';
import { TaskCreate } from './components/TaskCreate';

const { Content } = Layout;

const useStyle = makeStyles({
    layout: {
        minHeight: '100vh', // 设置布局的最小高度为视口高度
    },
    container: {
        padding: 0,
        margin: 0,
        top: 0,
        display: 'flex',
        flex: 1,
        width: '100%',
        flexDirection: 'column', // 垂直方向布局
    },
    new_task: {
        padding: 10,
        margin: 10,
        display: 'flex',
        flexDirection: 'row', // 水平方向布局
    },
})

const columns = [
    {
        title: '标题',
        dataIndex: 'title',
        key: 'title',
    },
    {
        title: '描述',
        dataIndex: 'description',
        key: 'description',
    },
    {
        title: '创建日期',
        dataIndex: 'created_at',
        key: 'created_at',
        render: (v: number) => {
            return <TimePipe timestamp={v} />;
        },
    },
    {
        title: '状态',
        dataIndex: 'status',
        key: 'status',
        render: (v: TaskStatus) => {
            return <Status status={v} />;
        }
    },
];

const TaskPage = () => {
    const style = useStyle();
    const { tasks } = useTaskStore();

    const [open_create, set_open_create] = useState(false); // 控制新建任务弹窗的显示和隐藏
    function onClickNewTask(e: React.MouseEvent<HTMLElement, MouseEvent>) {
        console.log('新建任务', e)
        set_open_create(true) // 显示新建任务弹窗
    }

    return (
        <>
        <TaskCreate open={open_create} set_open={set_open_create} />
        <Layout className={style.layout}> 
            <HeaderNav />
            <Layout>
                <SideNav />
                <Content
                    className={style.container}
                >
                    <div className={style.new_task}>
                        <Button type='primary' onClick={(e) => onClickNewTask(e)}>新建任务</Button>
                    </div>
                    <Table<Task>
                        columns={columns}
                        dataSource={tasks.map((v) => ({ ...v, key: v.id }))}
                        expandable={{
                            expandedRowRender: (v) => <p style={{ margin: 0 }}>{v.description}</p>,
                        }}
                    />
                </Content>
            </Layout>
        </Layout>
        </>
    );
};

export default TaskPage;