import { makeStyles } from "@mui/styles"
import { Modal, Collapse } from "antd"
import { DndContext, } from '@dnd-kit/core'
import { SortableContext, useSortable, verticalListSortingStrategy } from '@dnd-kit/sortable';
import { CSS } from '@dnd-kit/utilities'
import { arrayMove } from '@dnd-kit/sortable'
import { JSX, useState } from "react"
import { Step } from "../../../interfaces/step";

const useStyle = makeStyles({
    footer: {
        display: 'flex',
        flexDirection: 'row',
    },
    dnd: {}
})

export interface TaskCreateProps {
    open: boolean,
    set_open: (v: boolean) => void
}

const steps: Step[] = [
    { id: 1, title: '步骤1', type: 'src' } as Step,
    { id: 2, title: '步骤2', type: 'mid' } as Step,
    { id: 3, title: '步骤3', type: 'mid' } as Step,
    { id: 4, title: '步骤4', type: 'mid' } as Step,
    { id: 5, title: '步骤5', type: 'mid' } as Step,
    { id: 6, title: '步骤6', type: 'mid' } as Step,
    { id: 7, title: '步骤7', type: 'dst' } as Step,
]


export const TaskCreate = (props: TaskCreateProps) => {
    const style = useStyle();
    const [items, setItems] = useState(steps);

    const onDragEnd = ({ active, over }: { active: any, over: any }) => {
        if (active.id !== over?.id) {
            setItems(items => {
                const oldIndex = items.findIndex(item => item.id === active.id);
                const newIndex = items.findIndex(item => item.id === over.id);
                return arrayMove(items, oldIndex, newIndex);
            });
        }
    };

    return (
        <div>
            <Modal
                width={{
                    xs: '90%',
                    sm: '80%',
                    md: '70%',
                    lg: '60%',
                    xxl: '50%',
                }}
                title="新建任务"
                open={props.open}
            >

                <SortableItem key={items[0].id} id={items[0].id} disabled>
                    <Collapse style={{flex:1}} items={[items[0]].map(v => { return { key: v.id, label: v.title, children: <p>hello</p> } })}>
                    </Collapse>
                </SortableItem>
                <DndContext onDragEnd={onDragEnd}>
                    <SortableContext items={items} strategy={verticalListSortingStrategy}>
                        {
                            items.filter(v => v.type === "mid").map(v => {
                                return (
                                    <SortableItem key={v.id} id={v.id}>
                                        <Collapse items={[{ key: v.id, label: v.title, children: <p>hello</p> }]} style={{ flex: 1 }}>
                                        </Collapse>
                                    </SortableItem>
                                )
                            })
                        }
                    </SortableContext>
                </DndContext>
                <SortableItem key={items[items.length - 1].id} id={items[items.length - 1].id} disabled>
                    <Collapse style={{flex:1}} items={[items[items.length - 1]].map(v => { return { key: v.id, label: v.title, children: <p>hello</p> } })}>
                    </Collapse>
                </SortableItem>
            </Modal>
        </div>
    );
};


const SortableItem = ({ id, children, disabled=false }: { id: number; children: JSX.Element;disabled? : boolean}) => {
    const { attributes, listeners, setNodeRef, transform, transition } = useSortable({ id });

    const style = {
        'transform': CSS.Transform.toString(transform),
        transition,
        'cursor': disabled? 'not-allowed': 'move',
        'background-color': 'white',
        'margin-bottom': 8,
        'border-radius': 4,
        'box-shadow': '0 2px 4px rgba(0,0,0,0.1)',
        'display': 'flex', // Add this line to make the item a flex container
        'flex-direction': 'row', // Add this line to set the direction of the flex container to row
        'padding': '10px',
    };

    return (
        <div ref={setNodeRef} style={style} {...attributes}>
            <div {...listeners} style={{
                padding: '8px 16px',
                borderRight: disabled?'2px solid red':'2px solid green',
                display: 'flex',
                justifyContent: 'center',
                alignItems: 'center',
                marginRight: 16
            }}>⋮⋮</div>
            {children}
        </div>
    );
};